BorderlineSMOTE
=======================================================================

.. currentmodule:: imbalanced_ensemble.sampler.over_sampling

.. autoclass:: BorderlineSMOTE

   

   
   .. rubric:: Methods

   .. autosummary::
   
      
      
        ~BorderlineSMOTE.fit
      
      
        ~BorderlineSMOTE.fit_resample
      
      
        ~BorderlineSMOTE.get_params
      
      
        ~BorderlineSMOTE.set_params
      
   
   

.. include:: ../../../back_references/imbalanced_ensemble.sampler.over_sampling.BorderlineSMOTE.examples

.. raw:: html

    <div style='clear:both'></div>